@@ -47,7 +47,7 @@ bool Debugger::isInstalled() const
 {
     QString tryexec = tryExec();
     if(tryexec.isEmpty()) {
-        qCDebug(DRKONQI_LOG) << "tryExec of" << name() << "is empty!";
+        qCDebug(DRKONQI_LOG) << "tryExec of" << codeName() << "is empty!";
         return false;
     }
 
@@ -56,7 +56,7 @@ bool Debugger::isInstalled() const
         || !QStandardPaths::findExecutable(tryexec, {QCoreApplication::applicationDirPath()}).isEmpty();
 }
 
-QString Debugger::name() const
+QString Debugger::displayName() const
 {
     return isValid() ? m_config->group("General").readEntry("Name") : QString();
 }
@@ -88,53 +88,46 @@ void Debugger::setUsedBackend(const QString & backendName)
 
 QString Debugger::command() const
 {
-    if (!isValid() || !m_config->hasGroup(m_backend)) {
-        return QString();
-    } else {
-        return m_config->group(m_backend).readPathEntry("Exec", QString());
-    }
+    return (isValid() && m_config->hasGroup(m_backend))
+        ? m_config->group(m_backend).readPathEntry("Exec", QString())
+        : QString();
 }
 
 QString Debugger::backtraceBatchCommands() const
 {
-    if (!isValid() || !m_config->hasGroup(m_backend)) {
-        return QString();
-    } else {
-        return m_config->group(m_backend).readEntry("BatchCommands");
-    }
+    return (isValid() && m_config->hasGroup(m_backend))
+        ? m_config->group(m_backend).readPathEntry("BatchCommands", QString())
+        : QString();
 }
 
 bool Debugger::runInTerminal() const
 {
-    if (!isValid() || !m_config->hasGroup(m_backend)) {
-        return false;
-    } else {
-        return m_config->group(m_backend).readEntry("Terminal", false);
-    }
+    return (isValid() && m_config->hasGroup(m_backend))
+        ? m_config->group(m_backend).readEntry("Terminal", false)
+        : false;
 }
 
 QString Debugger::backendValueOfParameter(const QString &key) const
 {
-    if (!isValid() || !m_config->hasGroup(m_backend)) {
-        return QString();
-    } else {
-        return m_config->group(m_backend).readEntry(key, QString());
-    }
+    return (isValid() && m_config->hasGroup(m_backend))
+        ? m_config->group(m_backend).readEntry(key, QString())
+        : QString();
 }
 
 //static
 void Debugger::expandString(QString & str, ExpandStringUsage usage, const QString & tempFile)
 {
     const CrashedApplication *appInfo = DrKonqi::crashedApplication();
-    QHash<QString, QString> map;
-    map[QLatin1String("progname")] = appInfo->name();
-    map[QLatin1String("execname")] = appInfo->fakeExecutableBaseName();
-    map[QLatin1String("execpath")] = appInfo->executable().absoluteFilePath();
-    map[QLatin1String("signum")] = QString::number(appInfo->signalNumber());
-    map[QLatin1String("signame")] = appInfo->signalName();
-    map[QLatin1String("pid")] = QString::number(appInfo->pid());
-    map[QLatin1String("tempfile")] = tempFile;
-    map[QLatin1String("thread")] = QString::number(appInfo->thread());
+    const QHash<QString, QString> map = {
+        { QLatin1String("progname"), appInfo->name() },
+        { QLatin1String("execname"), appInfo->fakeExecutableBaseName() },
+        { QLatin1String("execpath"), appInfo->executable().absoluteFilePath() },
+        { QLatin1String("signum"), QString::number(appInfo->signalNumber()) },
+        { QLatin1String("signame"), appInfo->signalName() },
+        { QLatin1String("pid"), QString::number(appInfo->pid()) },
+        { QLatin1String("tempfile"), tempFile },
+        { QLatin1String("thread"), QString::number(appInfo->thread()) },
+    };
 
     if (usage == ExpansionUsageShell) {
         str = KMacroExpander::expandMacrosShellQuote(str, map);
@@ -146,24 +139,28 @@ void Debugger::expandString(QString & str, ExpandStringUsage usage, const QStrin
 //static
 QList<Debugger> Debugger::availableDebuggers(const QString & path, const QString & backend)
 {
-    QStringList debuggerDirs {
-        // Search in default path
-        QStandardPaths::locate(QStandardPaths::AppDataLocation, path, QStandardPaths::LocateDirectory),
+    const QStringList debuggerDirs {
         // Search from application path, this helps when deploying an application
-        QString(QStringLiteral("%1/%2")).arg(QCoreApplication::applicationDirPath(), path)
+        // as binary blob (e.g. Windows exe).
+        QCoreApplication::applicationDirPath() + QLatin1Char('/') + path,
+        // Search in default path
+        QStandardPaths::locate(QStandardPaths::AppDataLocation, path, QStandardPaths::LocateDirectory)
     };
-    QList<Debugger> result;
 
-    for (const auto & debuggerDir: debuggerDirs) {
-        QStringList debuggers = QDir(debuggerDir).entryList(QDir::Files);
-        for (const auto & debuggerFile : debuggers) {
+    QHash<QString, Debugger> result;
+    for (const auto &debuggerDir : qAsConst(debuggerDirs)) {
+        const QStringList debuggers = QDir(debuggerDir).entryList(QDir::Files);
+        for (const auto &debuggerFile : qAsConst(debuggers)) {
             Debugger debugger;
-            debugger.m_config = KSharedConfig::openConfig(QString(QStringLiteral("%1/%2")).arg(debuggerDir, debuggerFile));
+            debugger.m_config = KSharedConfig::openConfig(debuggerDir + QLatin1Char('/') + debuggerFile);
+            if (result.contains(debugger.codeName())) {
+                continue; // Already found in a higher priority location
+            }
             if (debugger.supportedBackends().contains(backend)) {
                 debugger.setUsedBackend(backend);
-                result.append(debugger);
+                result.insert(debugger.codeName(), debugger);
             }
         }
     }
-    return result;
+    return result.values();
 }
